summaryrefslogtreecommitdiff
path: root/tests/diagnostics
diff options
context:
space:
mode:
authorYong He <yonghe@outlook.com>2024-03-01 15:24:16 -0800
committerGitHub <noreply@github.com>2024-03-01 15:24:16 -0800
commit9a1e327387ffa8552ac2f0aee8836a0b10a5578f (patch)
tree2efdf8c0a62d517c615ef049d1b2ae6f75c630cf /tests/diagnostics
parente752a957c452abc1db2e160c738496b47aad2858 (diff)
Make slangc commandline parsing compatible with renderdoc. (#3658)
* Make slangc commandline parsing compatible with renderdoc. * Fix tests.
Diffstat (limited to 'tests/diagnostics')
-rw-r--r--tests/diagnostics/command-line/duplicate-target.slang2
-rw-r--r--tests/diagnostics/gh-38-vs.hlsl4
2 files changed, 3 insertions, 3 deletions
diff --git a/tests/diagnostics/command-line/duplicate-target.slang b/tests/diagnostics/command-line/duplicate-target.slang
index a9ec96d0f..b1fc8088a 100644
--- a/tests/diagnostics/command-line/duplicate-target.slang
+++ b/tests/diagnostics/command-line/duplicate-target.slang
@@ -1,3 +1,3 @@
// duplicate-target.slang
-//DIAGNOSTIC_TEST:SIMPLE:-target hlsl -target hlsl
+//DIAGNOSTIC_TEST:SIMPLE:-target hlsl -target spirv -target hlsl
diff --git a/tests/diagnostics/gh-38-vs.hlsl b/tests/diagnostics/gh-38-vs.hlsl
index 3e61d7f2e..15dd04847 100644
--- a/tests/diagnostics/gh-38-vs.hlsl
+++ b/tests/diagnostics/gh-38-vs.hlsl
@@ -1,4 +1,4 @@
//DIAGNOSTIC_TEST:SIMPLE: -profile sm_5_0 -entry main -stage vertex tests/diagnostics/gh-38-fs.hlsl -entry main -stage fragment -no-codegen
// Ensure that we catch errors with overlapping or conflicting parameter bindings.
@@ -6,4 +6,4 @@ Texture2D overlappingA : register(t0);
Texture2D conflicting : register(t1);
-float4 main() : SV_Position { return 0; }
+float4 main1() : SV_Position { return 0; }
@@ -1,4 +1,4 @@
-//DIAGNOSTIC_TEST:SIMPLE: -profile sm_5_0 -entry main -stage vertex tests/diagnostics/gh-38-fs.hlsl -entry main -stage fragment -no-codegen
+//DIAGNOSTIC_TEST:SIMPLE: -profile sm_5_0 -entry main1 -stage vertex tests/diagnostics/gh-38-fs.hlsl -entry main -stage fragment -no-codegen
// Ensure that we catch errors with overlapping or conflicting parameter bindings.